Informes | OiRA

Temas

# Informes

Puede utilizar un informe para:

- Aportar pruebas a las autoridades de control.
- Transmitir información a las personas afectadas (trabajadores, representantes de seguridad, empresarios, expertos en seguridad y salud en el trabajo, etc.)
- Supervisar y evaluar si se han adoptado las medidas necesarias;
- Registrar cualquier revisión si las circunstancias cambian (máquinas nuevas, trabajadores nuevos, como resultado de las conclusiones de cualquier investigación de accidentes, etc.)

Puede usted guardar el informe en su ordenador e imprimirlo. También puede modificarlo o añadir más información. Tenga en cuenta que los cambios realizados en un informe que ha descargado NO se guardarán en la herramienta OiRA.

## Opciones de informe

Existen diferentes tipos de informes disponibles para diferentes fines. La selección de los informes disponibles para las herramientas específicas depende de las decisiones adoptadas por el socio o el desarrollador nacional de la herramienta OiRA.

Informes disponibles

### Informe completo

Formato: Word/Office Open XML (.docx): puede editarlo después de descargarlo.

Proporciona: toda la información y las entradas consignadas por usted durante el proceso de evaluación de riesgos.

Utilícelo para:

- Aportar pruebas de la evaluación de riesgos a las autoridades de control (inspección de trabajo).

### Plan de acción

Formato: Excel/Office Open XML (.xlsx): puede editarlo después de descargarlo.

Proporciona: información sobre todas las medidas que ha decidido adoptar.

Utilícelo para:

- Hacer un seguimiento activo de la aplicación de las medidas por las que haya optado
- Gestionar los problemas/riesgos en su lugar de trabajo (tareas específicas, conocimientos especializados, responsabilidades, plazos).

### Descripción general de los riesgos

Formato: formato de documento portátil (.pdf): no puede editarlo después de descargarlo.

Proporciona: una visión general de los riesgos identificados.

Utilícelo para:

- Obtener una visión general rápida del estado de los riesgos en su centro de trabajo.
- Transmitir información a las personas interesadas.
- Supervisar si se están tratando de forma adecuada los riesgos y las medidas.

### Visión general de las medidas

Formato: formato de documento portátil (.pdf): no puede editarse después de descargarse.

Proporciona: una visión general rápida de las medidas que deben aplicarse.

Utilícelo para:

- Obtener una visión general rápida del estado de las medidas que ha decidido aplicar.
- Transmitir información a las personas interesadas.
- Supervisar si se están tratando de forma adecuada los riesgos y las medidas.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More